from rest_framework import serializers
from .models import Device
from api.serializers import CustomReadOnlyUserSerializer


class CreateDeviceSerializer(serializers.ModelSerializer):
    name = serializers.CharField(required=True)
    mac = serializers.CharField(required=True)
    registered = serializers.BooleanField(required=True)

    class Meta:
        model = Device
        fields = ["name", "mac", "registered", "blocked_by"]


class BlockDeviceSerializer(serializers.ModelSerializer):
    blocked = serializers.BooleanField(required=True)
    reason_for_blocking = serializers.CharField(required=True)
    blocked_by = serializers.ChoiceField(
        choices=[("ADMIN", "Admin"), ("PARENT", "Parent")], required=True
    )

    class Meta:
        model = Device
        fields = ["blocked", "reason_for_blocking", "blocked_by"]


class DeviceSerializer(serializers.ModelSerializer):
    class Meta:
        model = Device
        fields = "__all__"


class ReadOnlyDeviceSerializer(serializers.ModelSerializer):
    user = CustomReadOnlyUserSerializer(read_only=True)

    class Meta:  # type: ignore
        depth = 2
        model = Device
        fields = "__all__"
